These functions allow to compute the smoothed densities of the weight of
evidence in cases and in controls from the crude probabilities.
Wdensities.crude is designed for the general case; if the model
probabilities reflect a spike-slab mixture distribution, where a high
proportion of values of the predictor are zero, then Wdensities.mix
will be more appropriate.
Wdensities.crude(y, W, xseq, adjust.bw = 1)Wdensities.mix(y, W, xseq, mixcomponent)
Binary outcome label (0 for controls, 1 for cases).
Weight of evidence.
Sequence of points where the curves should be sampled.
Bandwidth adjustment.
integer vector same length as y, coded 1 or 2.
Typically set by Wdensities which calls this function.
List of crude densities for controls and cases sampled at each point in the range provided.